@@ -1,4 +1,4 @@
-from jsonschema import validate
+"""A module for storing data schema."""
 
 
 NAMED_SCHEMA = {
@@ -7,10 +7,10 @@ NAMED_SCHEMA = {
         "type": "object",
         "properties": {
             "name": {"type": "string"},
-            "values": {"type": "array"},
+            "values": {"type": "array", "optional": True},
             "type": {"type": "string", "optional": True},
         },
-        "required": ["name", "values"],
+        "required": ["name"],
     },
 }
 
@@ -40,9 +40,3 @@ DATA_SCHEMA = {
         },
     ],
 }
-
-
-class DataSchema:
-    @staticmethod
-    def validate(data):
-        validate(data, DATA_SCHEMA)
